@@ -7,6 +7,8 @@ from typing import TYPE_CHECKING
 
 import redis
 
+from spellbot.constants import REALLY_OLD_GAMES_HOURS
+
 if TYPE_CHECKING:  # pragma: no cover
     from spellbot import SpellBot
 
@@ -58,23 +60,30 @@ async def cleanup_old_voice_channels(bot: SpellBot) -> None:
     logger.info("starting old voice channels cleanup task...")
     async with bot.session() as session:
         for game in Game.voiced(session):
+            logger.info(f"checking voice channel for game {game.id}")
             assert game.voice_channel_xid
             chan = await safe_fetch_channel(bot, game.voice_channel_xid, game.guild_xid)
             if not chan:
+                logger.info(f"could not fetch voice channel for game {game.id}")
                 game.voice_channel_xid = None  # type: ignore
                 game.voice_channel_invite = None  # type: ignore
                 continue
 
             empty_or_really_old = (
                 not chan.voice_states.keys()  # type: ignore
-                or datetime.utcnow() >= game.updated_at + timedelta(hours=7)
+                or datetime.utcnow()
+                >= game.updated_at + timedelta(hours=REALLY_OLD_GAMES_HOURS)
             )
             if empty_or_really_old:
+                logger.info(f"deleting voice channel for game {game.id}")
                 success = await safe_delete_channel(chan, game.guild_xid)
                 if success:
+                    logger.info(f"deleted voice channel for game {game.id}")
                     game.voice_channel_xid = None  # type: ignore
                     game.voice_channel_invite = None  # type: ignore
+                    session.commit()
                 else:
+                    logger.info(f"failed to delete voice channel for game {game.id}")
                     guild = bot.get_guild(game.guild_xid)
                     perms = guild.me.permissions_in(chan)
                     chan_name = chan.name  # type: ignore
@@ -84,7 +93,6 @@ async def cleanup_old_voice_channels(bot: SpellBot) -> None:
                         f" {perms.value}"
                     )
                     logger.info(msg)
-        session.commit()
 
 
 async def cleanup_started_games(bot: SpellBot) -> None:
@@ -93,7 +101,8 @@ async def cleanup_started_games(bot: SpellBot) -> None:
     async with bot.session() as session:
         games = session.query(Game).filter(Game.status == "started").all()
         for game in games:
-            game.tags = []  # cascade delete tag associations
+            # cascade delete tag associations
+            game.tags = []  # type: ignore
             session.delete(game)
         session.commit()
 
